@@ -47,10 +47,10 @@ class ListView : public QListView, public QDeclarativeParserStatus
     Q_PROPERTY(AnchorLine verticalCenter READ verticalCenter CONSTANT FINAL)
     Q_PROPERTY(bool interactive READ interactive WRITE setInteractive NOTIFY interactiveChanged)
     Q_PROPERTY(bool moving READ moving NOTIFY movingChanged)
-    Q_PROPERTY(bool atXBeginning READ atXBeginning NOTIFY contentXChanged)
-    Q_PROPERTY(bool atXEnd READ atXEnd NOTIFY contentXChanged)
-    Q_PROPERTY(bool atYBeginning READ atYBeginning NOTIFY contentYChanged)
-    Q_PROPERTY(bool atYEnd READ atYEnd NOTIFY contentYChanged)
+    Q_PROPERTY(bool atXBeginning READ atXBeginning NOTIFY atXBeginningChanged)
+    Q_PROPERTY(bool atXEnd READ atXEnd NOTIFY atXEndChanged)
+    Q_PROPERTY(bool atYBeginning READ atYBeginning NOTIFY atYBeginningChanged)
+    Q_PROPERTY(bool atYEnd READ atYEnd NOTIFY atYEndChanged)
     Q_PROPERTY(int contentX READ contentX WRITE setContentX NOTIFY contentXChanged)
     Q_PROPERTY(int contentY READ contentY WRITE setContentY NOTIFY contentYChanged)
     Q_PROPERTY(qreal flickDeceleration READ flickDeceleration WRITE setFlickDeceleration NOTIFY flickDecelerationChanged)
@@ -127,6 +127,10 @@ signals:
     void focusChanged();
     void interactiveChanged();
     void movingChanged();
+    void atXBeginningChanged();
+    void atXEndChanged();
+    void atYBeginningChanged();
+    void atYEndChanged();
     void contentXChanged();
     void contentYChanged();
     void flickDecelerationChanged();
@@ -154,6 +158,10 @@ protected:
 
     Q_DECLARE_PRIVATE(ListView)
 
+    Q_PRIVATE_SLOT(d_func(), void _q_onHorizontalScrollPositionChanged())
+    Q_PRIVATE_SLOT(d_func(), void _q_onVerticalScrollPositionChanged())
+    Q_PRIVATE_SLOT(d_func(), void _q_onScrollingStopped())
+
 private:
     Q_DISABLE_COPY(ListView)
 };
