@@ -72,19 +72,6 @@ void TabGroup::setOpacity(qreal opacity) {
     }
 }
 
-void TabGroup::setFocus(bool focus) {
-    Q_D(const TabGroup);
-
-    if ((d->complete) && (focus != this->hasFocus())) {
-        if (focus) {
-            this->setFocus(Qt::OtherFocusReason);
-        }
-        else {
-            this->clearFocus();
-        }
-    }
-}
-
 AnchorLine TabGroup::left() const {
     Q_D(const TabGroup);
 
@@ -126,6 +113,9 @@ void TabGroup::changeEvent(QEvent *event) {
     case QEvent::ParentChange:
         emit parentChanged();
         break;
+    case QEvent::EnabledChange:
+        emit enabledChanged();
+        break;
     default:
         break;
     }
@@ -188,10 +178,8 @@ void TabGroup::componentComplete() {
         this->setWindowFlags(Qt::Widget);
     }
 
-    foreach (QObject *obj, d->dataList) {
-        if (QWidget *widget = qobject_cast<QWidget*>(obj)) {
-            this->addWidget(widget);
-        }
+    foreach (QWidget *widget, d->childrenList) {
+        this->addWidget(widget);
     }
 
     if (d->qmlVisible()) {
@@ -207,10 +195,6 @@ void TabGroupPrivate::data_append(QDeclarativeListProperty<QObject> *list, QObje
     if (TabGroup *stack = qobject_cast<TabGroup*>(list->object)) {
         stack->d_func()->dataList.append(obj);
 
-        if (!stack->d_func()->complete) {
-            return;
-        }
-
         if (QWidget *widget = qobject_cast<QWidget*>(obj)) {
             stack->d_func()->childrenList.append(widget);
 
