@@ -71,19 +71,6 @@ void ValueButton::setOpacity(qreal opacity) {
     }
 }
 
-void ValueButton::setFocus(bool focus) {
-    Q_D(const ValueButton);
-
-    if ((d->complete) && (focus != this->hasFocus())) {
-        if (focus) {
-            this->setFocus(Qt::OtherFocusReason);
-        }
-        else {
-            this->clearFocus();
-        }
-    }
-}
-
 QString ValueButton::iconSource() const {
     return this->icon().name();
 }
@@ -160,6 +147,9 @@ void ValueButton::changeEvent(QEvent *event) {
     case QEvent::ParentChange:
         emit parentChanged();
         break;
+    case QEvent::EnabledChange:
+        emit enabledChanged();
+        break;
     default:
         break;
     }
@@ -202,12 +192,12 @@ void ValueButton::hideEvent(QHideEvent *event) {
 }
 
 void ValueButton::focusInEvent(QFocusEvent *event) {
-    emit visibleChanged();
+    emit focusChanged();
     QMaemo5ValueButton::focusInEvent(event);
 }
 
 void ValueButton::focusOutEvent(QFocusEvent *event) {
-    emit visibleChanged();
+    emit focusChanged();
     QMaemo5ValueButton::focusOutEvent(event);
 }
 
