@@ -125,19 +125,6 @@ void Window::setOpacity(qreal opacity) {
     }
 }
 
-void Window::setFocus(bool focus) {
-    Q_D(const Window);
-
-    if ((d->complete) && (focus != this->hasFocus())) {
-        if (focus) {
-            this->setFocus(Qt::OtherFocusReason);
-        }
-        else {
-            this->clearFocus();
-        }
-    }
-}
-
 AnchorLine Window::left() const {
     Q_D(const Window);
 
@@ -189,6 +176,9 @@ void Window::changeEvent(QEvent *event) {
     case QEvent::ParentChange:
         emit parentChanged();
         break;
+    case QEvent::EnabledChange:
+        emit enabledChanged();
+        break;
     default:
         break;
     }
